"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.JQueryODataClient = exports.getV2OrV4ErrorMessage = void 0;
const AjaxConfig_1 = require("./AjaxConfig");
const getV2OrV4ErrorMessage = (errorResponse) => {
    var _a;
    const eMsg = (_a = errorResponse === null || errorResponse === void 0 ? void 0 : errorResponse.error) === null || _a === void 0 ? void 0 : _a.message;
    return typeof (eMsg === null || eMsg === void 0 ? void 0 : eMsg.value) === "string" ? eMsg.value : eMsg;
};
exports.getV2OrV4ErrorMessage = getV2OrV4ErrorMessage;
class JQueryODataClient {
    constructor(jquery, config, clientOptions) {
        this.clientOptions = clientOptions;
        this.getErrorMessage = exports.getV2OrV4ErrorMessage;
        this.client = jquery;
        this.config = (0, AjaxConfig_1.getDefaultConfig)(config);
    }
    setErrorMessageRetriever(getErrorMsg) {
        this.getErrorMessage = getErrorMsg;
    }
    sendRequest(config, requestConfig) {
        const mergedConfig = (0, AjaxConfig_1.mergeAjaxConfig)((0, AjaxConfig_1.mergeAjaxConfig)(this.config, requestConfig), config);
        return new Promise((resolve, reject) => {
            this.client.ajax(Object.assign(Object.assign({}, mergedConfig), { success: (response, textStatus, jqXHR) => {
                    resolve({
                        status: jqXHR.status,
                        statusText: jqXHR.statusText,
                        headers: jqXHR.getAllResponseHeaders(),
                        data: response,
                    });
                }, error: (jqXHR, textStatus, thrownError) => {
                    const message = this.getErrorMessage(jqXHR.responseJSON);
                    reject(Object.assign(new Error(), {
                        status: jqXHR.status || 0,
                        code: jqXHR.statusText,
                        data: jqXHR.responseJSON,
                        message,
                    }));
                } }));
            // return this.handleError();
        });
    }
    post(url, data, requestConfig) {
        return this.sendRequest({ url, data, method: "POST" }, requestConfig);
    }
    get(url, requestConfig) {
        return this.sendRequest({ url, method: "GET" }, requestConfig);
    }
    put(url, data, requestConfig) {
        return this.sendRequest({ url, data, method: "PUT" }, requestConfig);
    }
    patch(url, data, requestConfig) {
        return this.sendRequest({ url, data, method: "PATCH" }, requestConfig);
    }
    merge(url, data, requestConfig) {
        const config = (0, AjaxConfig_1.mergeAjaxConfig)(requestConfig, {
            headers: {
                "X-Http-Method": "MERGE",
            },
        });
        return this.sendRequest({ url, data, method: "POST" }, config);
    }
    delete(url, requestConfig) {
        return this.sendRequest({ url, method: "DELETE" }, requestConfig);
    }
}
exports.JQueryODataClient = JQueryODataClient;
//# sourceMappingURL=JQueryODataClient.js.map